Calibrate Accelerometer Data using `agcounts`
calibrate.RdThis uses the van Hees calibration method typically exposed through GGIR, implemented here via `agcounts::agcalibrate()`.
Usage
acti_calibrate(
data,
verbose = TRUE,
fill_zeroes = TRUE,
round_after_calibration = TRUE,
...
)Arguments
- data
Either a GT3X file, `AccData` object, or `data.frame` with `X/Y/Z` and `time`
- verbose
print diagnostic messages, higher number result in higher verbosity
- fill_zeroes
Should `actibase::acti_fill_zeros()` be run before calculating the measures? This trims zero values from the beginning and the end of the time course using last observation carried forward behavior.
- round_after_calibration
Should the data be rounded after calibration? Will round to 3 digits
- ...
Additional arguments to pass to `agcounts::agcalibrate()`
Examples
if (FALSE) { # \dontrun{
res = acti_calibrate(data = actiread::acti_example_gt3x())
} # }