Perform step count calculation in a separate Python environment
py_acti_calculate_stepcount.RdPerform step count calculation in a separate Python environment
Usage
py_acti_calculate_stepcount(
...,
pyenv_function = function() {
reticulate::import("stepcount")
},
show = FALSE
)Arguments
- ...
arguments passed to
acti_calculate_stepcount()- pyenv_function
function that loads the
stepcountPython package. By default, it usesreticulate::py_import("stepcount")to import the package. If this function has anargsargument, the output ofpyenv_functionwill be re-assigned toargs.- show
Logical, whether to show the standard output on the screen while the child process is running, passed to
callr::r()
Value
The output from acti_calculate_stepcount().
A tibble with minute-level time, steps, and walking columns.
Examples
if (FALSE) { # \dontrun{
data = actiread::acti_read_gt3x(actiread::acti_example_gt3x())
steps = py_acti_calculate_stepcount(data, sample_rate = 100)
} # }